CoinBalanceBreakdown class

An owner's balance for a coin type, split into its two sources: coinBalance held in owned coin objects and addressBalance held in the account's per-address accumulator. total is their sum.

Constructors

CoinBalanceBreakdown({required BigInt total, required BigInt addressBalance, required BigInt coinBalance})

Properties

addressBalance BigInt
final
coinBalance BigInt
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total BigInt
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited