SuiBalance class

Constructors

SuiBalance({required String coinType, required BigInt totalBalance, required BigInt addressBalance, required BigInt coinBalance})
SuiBalance.fromProto(Balance b)
factory

Properties

addressBalance BigInt
final
coinBalance BigInt
final
coinType String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalBalance BigInt
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited