SuiCoin class

Constructors

SuiCoin({required String coinType, required String coinObjectId, required BigInt version, required String digest, required BigInt balance})

Properties

balance BigInt
final
coinObjectId String
final
coinType String
final
digest String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version BigInt
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited