SuiGasCost class

Constructors

SuiGasCost({required BigInt computationCost, required BigInt storageCost, required BigInt storageRebate})

Properties

computationCost BigInt
final
hashCode int
The hash code for this object.
no setterinherited
net BigInt
Net gas charged = computation + storage - rebate.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storageCost BigInt
final
storageRebate BigInt
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited