SuiObjectInfo class

Constructors

SuiObjectInfo({required String objectId, required BigInt version, required String digest, required String? type, required SuiOwner? owner})
SuiObjectInfo.fromProto(Object o)
factory

Properties

digest String
final
hashCode int
The hash code for this object.
no setterinherited
objectId String
final
owner SuiOwner?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
final
version BigInt
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited