SuiOwner class
Constructors
- SuiOwner({required SuiOwnerKind kind, String? address, })
- SuiOwner.fromProto(Owner o)
-
factory
Properties
- address → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
final
- kind → SuiOwnerKind
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited