Ed25519Keypair class

Mixed-in types

Constructors

Ed25519Keypair([Uint8List? secretKey])
Create a new Ed25519 keypair instance. Generate random keypair if no Ed25519Keypair is provided.
Ed25519Keypair.fromSecretKey(Uint8List secretKey, {bool skipValidation = true})
Create a Ed25519 keypair from a raw secret key byte array.
factory
Ed25519Keypair.fromSeed(Uint8List seed)
Generate a Ed25519 keypair from a 32 byte seed.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getKeyScheme() → SignatureScheme
Get the key scheme of the keypair: Secp256k1 or Ed25519
override
getPublicKey() → Ed25519PublicKey
The public key for this Ed25519 keypair
override
getSecretKey() → Uint8List
The secret key for this keypair
override
keyPair() → KeyPair
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
publicKeyBytes() → Uint8List
sign(Uint8List bytes) → Uint8List
inherited
signData(Uint8List data) → Uint8List
Return the signature for the provided data using Ed25519.
override
signPersonalMessage(Uint8List bytes) → SignatureWithBytes
inherited
signTransactionBlock(Uint8List bytes) → SignatureWithBytes
inherited
signWithIntent(Uint8List bytes, IntentScope intent) → SignatureWithBytes
inherited
toString() → String
A string representation of this object.
inherited
verify(Uint8List data, Uint8List signature, Uint8List publicKey) → bool
Verify signature
override
verifyPersonalMessage(Uint8List message, String signature) → bool
Verifies that the signature is valid for for the provided PersonalMessage
inherited
verifySerialized(Uint8List message, String signature, Uint8List publicKey) → bool
Verify serialized signature
override
verifyTransaction(Uint8List transaction, String signature) → bool
inherited
verifyWithIntent(Uint8List bytes, String signature, IntentScope intent) → bool
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

deriveKeypair(String path, String mnemonics) → Ed25519Keypair
Derive Ed25519 keypair from mnemonics and path. The mnemonics must be normalized and validated against the english wordlist.
fromMnemonics(String mnemonics, {int accountIndex = 0, int addressIndex = 0, int changeIndex = 0}) → Ed25519Keypair
Generate a keypair from mnemonics string.