PasskeyAssertion class
The result of a passkey assertion (WebAuthn get).
Constructors
- PasskeyAssertion(Uint8List authenticatorData, Uint8List clientDataJSON, Uint8List signature)
Properties
- authenticatorData → Uint8List
-
final
- clientDataJSON → Uint8List
-
The clientDataJSON, UTF-8 encoded (as returned by the authenticator).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature → Uint8List
-
The DER-encoded secp256r1 signature over
authenticatorData || sha256(clientDataJSON).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited