PasskeyPublicKey class

A passkey public key. Mirrors Mysten's PasskeyPublicKey (SIP-9): flag 0x06, 33-byte compressed secp256r1 point.

Mixed-in types

Constructors

PasskeyPublicKey(Uint8List value)
PasskeyPublicKey.fromBase64(String base64String)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

equals(PublicKey publicKey) → bool
Checks if two public keys are equal
inherited
flag() → int
Return signature scheme flag of the public key
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBase64() → String
Return the base-64 representation of the public key
override
toRawBytes() → Uint8List
Return the byte array representation of the public key
override
toString() → String
A string representation of this object.
override
toSuiAddress() → String
Sui address = blake2b256(flag(0x06) || compressedPubKey)[:32].
override
toSuiBytes() → Uint8List
Returns the bytes representation of the public key prefixed with the signature scheme flag
inherited
toSuiPublicKey() → String
Return the Sui representation of the public key encoded in base-64. A Sui public key is formed by the concatenation of the scheme flag with the raw bytes of the public key
inherited
verify(Uint8List message, Uint8List signature) → bool
Verifies a serialized passkey signature over message (the challenge the passkey signed, i.e. blake2b(intentMessage)).
override
verifyPersonalMessage(Uint8List message, String signature) → bool
inherited
verifyTransaction(Uint8List transaction, String signature) → bool
inherited
verifyWithIntent(Uint8List bytes, String signature, IntentScope intent) → bool
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited