EpochSummary class

Constructors

EpochSummary({required int epochId, required BigInt referenceGasPrice, required int? totalTransactions, required String? startTimestamp, required String? endTimestamp})

Properties

endTimestamp String?
final
epochId int
final
hashCode int
The hash code for this object.
no setterinherited
referenceGasPrice BigInt
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTimestamp String?
final
totalTransactions int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited