SenderTransactionPage class

A page of a sender's transactions with the fields wallets show per row.

Constructors

SenderTransactionPage({required List<SenderTransaction> transactions, required bool hasNextPage, String? endCursor})

Properties

digests List<String>
The digests of the transactions in this page.
no setter
endCursor String?
final
hashCode int
The hash code for this object.
no setterinherited
hasNextPage bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transactions List<SenderTransaction>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited