SystemParameters class

Available extensions

Constructors

SystemParameters({Int64? epochDurationMs, Int64? stakeSubsidyStartEpoch, Int64? minValidatorCount, Int64? maxValidatorCount, Int64? minValidatorJoiningStake, Int64? validatorLowStakeThreshold, Int64? validatorVeryLowStakeThreshold, Int64? validatorLowStakeGracePeriod, MoveTable? extraFields})
factory
SystemParameters.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
SystemParameters.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

epochDurationMs ↔ Int64
The duration of an epoch, in milliseconds.
getter/setter pair
extraFields MoveTable
Any extra fields that are not defined statically.
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
maxValidatorCount ↔ Int64
Maximum number of active validators at any moment. We do not allow the number of validators in any epoch to go above this.
getter/setter pair
minValidatorCount ↔ Int64
Minimum number of active validators at any moment.
getter/setter pair
minValidatorJoiningStake ↔ Int64
Deprecated. Lower-bound on the amount of stake required to become a validator.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stakeSubsidyStartEpoch ↔ Int64
The starting epoch in which stake subsidies start being paid out
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
validatorLowStakeGracePeriod ↔ Int64
A validator can have stake below validator_low_stake_threshold for this many epochs before being kicked out.
getter/setter pair
validatorLowStakeThreshold ↔ Int64
Deprecated. Validators with stake amount below validator_low_stake_threshold are considered to have low stake and will be escorted out of the validator set after being below this threshold for more than validator_low_stake_grace_period number of epochs.
getter/setter pair
validatorVeryLowStakeThreshold ↔ Int64
Deprecated. Validators with stake below validator_very_low_stake_threshold will be removed immediately at epoch change, no grace period.
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearEpochDurationMs() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearExtraFields() → void
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearMaxValidatorCount() → void
clearMinValidatorCount() → void
clearMinValidatorJoiningStake() → void
clearStakeSubsidyStartEpoch() → void
clearValidatorLowStakeGracePeriod() → void
clearValidatorLowStakeThreshold() → void
clearValidatorVeryLowStakeThreshold() → void
clone() SystemParameters
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
copyWith(void updates(SystemParameters)) SystemParameters
Apply updates to a copy of this message.
createEmptyInstance() SystemParameters
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureExtraFields() MoveTable
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasEpochDurationMs() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasExtraFields() bool
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasMaxValidatorCount() bool
hasMinValidatorCount() bool
hasMinValidatorJoiningStake() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasStakeSubsidyStartEpoch() bool
hasValidatorLowStakeGracePeriod() bool
hasValidatorLowStakeThreshold() bool
hasValidatorVeryLowStakeThreshold() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited