SystemState class

Available extensions

Constructors

SystemState({Int64? version, Int64? epoch, Int64? protocolVersion, ValidatorSet? validators, StorageFund? storageFund, SystemParameters? parameters, Int64? referenceGasPrice, Iterable<ValidatorReportRecord>? validatorReportRecords, StakeSubsidy? stakeSubsidy, bool? safeMode, Int64? safeModeStorageRewards, Int64? safeModeComputationRewards, Int64? safeModeStorageRebates, Int64? safeModeNonRefundableStorageFee, Int64? epochStartTimestampMs, MoveTable? extraFields})
factory
SystemState.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
SystemState.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

epoch ↔ Int64
The epoch id
getter/setter pair
epochStartTimestampMs ↔ Int64
Unix timestamp of when this this epoch started
getter/setter pair
extraFields MoveTable
Any extra fields that's not defined statically.
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
parameters SystemParameters
Set of system config parameters
getter/setter pair
protocolVersion ↔ Int64
The protocol version
getter/setter pair
referenceGasPrice ↔ Int64
The reference gas price for this epoch
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
safeMode bool
Whether the system is running in a downgraded safe mode due to a non-recoverable bug. This is set whenever we failed to execute advance_epoch, and ended up executing advance_epoch_safe_mode. It can be reset once we are able to successfully execute advance_epoch. The rest of the fields starting with safe_mode_ are accumulated during safe mode when advance_epoch_safe_mode is executed. They will eventually be processed once we are out of safe mode.
getter/setter pair
safeModeComputationRewards ↔ Int64
Computation rewards accumulated during safe_mode
getter/setter pair
safeModeNonRefundableStorageFee ↔ Int64
Nonrefundable storage fees accumulated during safe_mode
getter/setter pair
safeModeStorageRebates ↔ Int64
Storage rebates paid out during safe_mode
getter/setter pair
safeModeStorageRewards ↔ Int64
Storage rewards accumulated during safe_mode
getter/setter pair
stakeSubsidy StakeSubsidy
Schedule of stake subsidies given out each epoch.
getter/setter pair
storageFund StorageFund
Storage Fund info
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
validatorReportRecords → PbList<ValidatorReportRecord>
A list of the records of validator reporting each other.
no setter
validators ValidatorSet
Information about the validators
getter/setter pair
version ↔ Int64
The version of the system state data structure type.
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearEpoch() → void
clearEpochStartTimestampMs() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearExtraFields() → void
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearParameters() → void
clearProtocolVersion() → void
clearReferenceGasPrice() → void
clearSafeMode() → void
clearSafeModeComputationRewards() → void
clearSafeModeNonRefundableStorageFee() → void
clearSafeModeStorageRebates() → void
clearSafeModeStorageRewards() → void
clearStakeSubsidy() → void
clearStorageFund() → void
clearValidators() → void
clearVersion() → void
clone() SystemState
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
copyWith(void updates(SystemState)) SystemState
Apply updates to a copy of this message.
createEmptyInstance() SystemState
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureExtraFields() MoveTable
ensureParameters() SystemParameters
ensureStakeSubsidy() StakeSubsidy
ensureStorageFund() StorageFund
ensureValidators() ValidatorSet
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasEpoch() bool
hasEpochStartTimestampMs() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasExtraFields() bool
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasParameters() bool
hasProtocolVersion() bool
hasReferenceGasPrice() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasSafeMode() bool
hasSafeModeComputationRewards() bool
hasSafeModeNonRefundableStorageFee() bool
hasSafeModeStorageRebates() bool
hasSafeModeStorageRewards() bool
hasStakeSubsidy() bool
hasStorageFund() bool
hasValidators() bool
hasVersion() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() SystemState
createRepeated() → PbList<SystemState>
getDefault() SystemState