ValidatorSet class

Available extensions

Constructors

ValidatorSet({Int64? totalStake, Iterable<Validator>? activeValidators, MoveTable? pendingActiveValidators, Iterable<Int64>? pendingRemovals, MoveTable? stakingPoolMappings, MoveTable? inactiveValidators, MoveTable? validatorCandidates, Iterable<MapEntry<String, Int64>>? atRiskValidators, MoveTable? extraFields})
factory
ValidatorSet.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
ValidatorSet.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

activeValidators → PbList<Validator>
The current list of active validators.
no setter
atRiskValidators → PbMap<String, Int64>
Table storing the number of epochs during which a validator's stake has been below the low stake threshold.
no setter
extraFields MoveTable
Any extra fields that's not defined statically.
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
inactiveValidators MoveTable
Mapping from a staking pool ID to the inactive validator that has that pool as its staking pool. When a validator is deactivated the validator is removed from active_validators it is added to this table so that stakers can continue to withdraw their stake from it.
getter/setter pair
info_ → BuilderInfo
no setter
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
pendingActiveValidators MoveTable
List of new validator candidates added during the current epoch. They will be processed at the end of the epoch.
getter/setter pair
pendingRemovals → PbList<Int64>
Removal requests from the validators. Each element is an index pointing to active_validators.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stakingPoolMappings MoveTable
Mappings from staking pool's ID to the sui address of a validator.
getter/setter pair
totalStake ↔ Int64
Total amount of stake from all active validators at the beginning of the epoch. Written only once per epoch, in advance_epoch function.
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
validatorCandidates MoveTable
Table storing preactive/candidate validators, mapping their addresses to their Validator structs. When an address calls request_add_validator_candidate, they get added to this table and become a preactive validator. When the candidate has met the min stake requirement, they can call request_add_validator to officially add them to the active validator set active_validators next epoch.
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearExtraFields() → void
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearInactiveValidators() → void
clearPendingActiveValidators() → void
clearStakingPoolMappings() → void
clearTotalStake() → void
clearValidatorCandidates() → void
clone() ValidatorSet
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
copyWith(void updates(ValidatorSet)) ValidatorSet
Apply updates to a copy of this message.
createEmptyInstance() ValidatorSet
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureExtraFields() MoveTable
ensureInactiveValidators() MoveTable
ensurePendingActiveValidators() MoveTable
ensureStakingPoolMappings() MoveTable
ensureValidatorCandidates() MoveTable
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasExtraFields() bool
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasInactiveValidators() bool
hasPendingActiveValidators() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasStakingPoolMappings() bool
hasTotalStake() bool
hasValidatorCandidates() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() ValidatorSet
createRepeated() → PbList<ValidatorSet>
getDefault() ValidatorSet