DynamicFieldInfo class abstract

Annotations
  • @freezed

Constructors

DynamicFieldInfo({required DynamicFieldName name, required String bcsName, required String type, required String objectType, required String objectId, required int version, required String digest})
const
factory
DynamicFieldInfo.fromJson(Map<String, dynamic> json)
factory

Properties

bcsName → String
no setterinherited
digest → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
name → DynamicFieldName
no setterinherited
objectId → String
no setterinherited
objectType → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
no setterinherited
version → int
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this DynamicFieldInfo to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited