SuiEvent class abstract

Annotations
  • @freezed

Constructors

SuiEvent({required EventId id, required String packageId, required String transactionModule, required String sender, required String type, required Map<String, dynamic>? parsedJson, required String? bcs})
const
factory
SuiEvent.fromJson(Map<String, dynamic> json)
factory

Properties

bcs → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → EventId
no setterinherited
packageId → String
no setterinherited
parsedJson → Map<String, dynamic>?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender → String
no setterinherited
transactionModule → String
no setterinherited
type → String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this SuiEvent to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited