JsonRpcClient class

Constructors

JsonRpcClient(String url, {RequestOptions? options})

Properties

hashCode → int
The hash code for this object.
no setterinherited
options ↔ RequestOptions?
getter/setter pair
rpcVersion → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
final

Methods

batchRequest(Iterable<Map<String, dynamic>> requests) → Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request(String method, [List? args]) → Future
sendRequest(String method, [dynamic parameters]) → Future
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited