RequestOptions class

Constructors

RequestOptions({Map<String, dynamic>? headers, Duration? connectTimeout, Duration? sendTimeout, Duration? receiveTimeout})

Properties

connectTimeout ↔ Duration?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ Map<String, dynamic>?
getter/setter pair
receiveTimeout ↔ Duration?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendTimeout ↔ Duration?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited