FaucetClient class

Constructors

FaucetClient(String endpoint)

Properties

endpoint String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestSuiFromFaucetV2(String recipient) Future<FaucetResponse>
Requests SUI from the faucet via the /v2/gas route.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited