CoinBalanceChangeEvent class

Constructors

CoinBalanceChangeEvent(ObjectId packageId, String transactionModule, SuiAddress sender, ObjectOwner owner, BalanceChangeType changeType, String coinType, ObjectId coinObjectId, SequenceNumber version, int amount)

Properties

amount ↔ int
getter/setter pair
changeType ↔ BalanceChangeType
getter/setter pair
coinObjectId ↔ String
getter/setter pair
coinType ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
owner ↔ ObjectOwner
getter/setter pair
packageId ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender ↔ String
getter/setter pair
transactionModule ↔ String
getter/setter pair
version ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited