MoveEvent class

Constructors

MoveEvent(ObjectId packageId, String transactionModule, SuiAddress sender, String type, Map<String, dynamic>? fields, String bcs)

Properties

bcs ↔ String
getter/setter pair
fields ↔ Map<String, dynamic>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
packageId ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender ↔ String
getter/setter pair
transactionModule ↔ String
getter/setter pair
type ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited