TransferObjectEvent class

Constructors

TransferObjectEvent(ObjectId packageId, String transactionModule, SuiAddress sender, ObjectOwner recipient, String objectType, ObjectId objectId, SequenceNumber version)

Properties

hashCode → int
The hash code for this object.
no setterinherited
objectId ↔ String
getter/setter pair
objectType ↔ String
getter/setter pair
packageId ↔ String
getter/setter pair
recipient ↔ ObjectOwner
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender ↔ String
getter/setter pair
transactionModule ↔ String
getter/setter pair
version ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited