GasData class

The GasData to be used in the transaction.

Constructors

GasData(List<SuiObjectRef> payment, String owner, int price, int budget)

Properties

budget ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
owner ↔ String
getter/setter pair
payment ↔ List<SuiObjectRef>
getter/setter pair
price ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited