GasCostSummary class

Constructors

GasCostSummary(int computationCost, int storageCost, int storageRebate, int nonRefundableStorageFee)
GasCostSummary.fromJson(dynamic data)
factory

Properties

computationCost ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nonRefundableStorageFee ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageCost ↔ int
getter/setter pair
storageRebate ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited