SuiPackage class

Constructors

SuiPackage(String digest, String objectId, int version)
SuiPackage.fromJson(dynamic data)
factory

Properties

digest ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
objectId ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited