Keys class

Constructors

Keys({Uint8List? key, Uint8List? chainCode})

Properties

chainCode → Uint8List?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Uint8List?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited