zklogin/utils library

Functions

findFirstNonZeroIndex(Uint8List bytes) → int
toBigEndianBytes(BigInt num, int width) → Uint8List
Derive bytearray from num where the bytearray is not padded with 0.
toPaddedBigEndianBytes(BigInt num, int width) → Uint8List
Derive bytearray from num where the bytearray is padded to the left with 0s to the specified width.