builder/transaction_builder_client library

Classes

ResolvedGasData
Result of one-shot server-side gas resolution: the gas payment the server selected and the budget it computed (and echoed gas price).
TransactionBuilderClient
Narrow interface of the data-provider capabilities the transaction Transaction builder needs during build():