ResolvedGasData class
Result of one-shot server-side gas resolution: the gas payment the server selected and the budget it computed (and echoed gas price).
Constructors
-
ResolvedGasData({required BigInt budget, required List<
SuiObjectRef> payment, BigInt? price})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited