TransactionBuilderClient class abstract
Narrow interface of the data-provider capabilities the transaction
Transaction builder needs during build():
- object reference resolution (
multiGetObjects) - Move function signature lookup (
getNormalizedMoveFunction) - gas price / gas coin selection / budget dry-run
Both the legacy JSON-RPC SuiClient and the new gRPC-backed adapter
implement this, so the builder is transport-agnostic.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dryRunTransaction<
T> (T tx, {String? signerAddress}) → Future< DryRunTransactionBlockResponse> -
getCoins(
String owner, {String? coinType, String? cursor, int? limit}) → Future< PaginatedCoins> -
getNormalizedMoveFunction(
String package, String moduleName, String functionName) → Future< SuiMoveNormalizedFunction> -
getProtocolConfig(
[String? version]) → Future -
getReferenceGasPrice(
) → Future< BigInt> -
multiGetObjects(
List< String> objectIds, {SuiObjectDataOptions? options}) → Future<List< SuiObjectResponse> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited