PasskeyProvider class abstract
Platform-agnostic passkey provider. The application supplies a WebAuthn
backed implementation (browser / iOS / Android); this SDK performs the
Sui-specific encoding. Mirrors Mysten's PasskeyProvider.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
) → Future< PasskeyRegistration> - Create a new passkey credential.
-
get(
Uint8List challenge, [Uint8List? credentialId]) → Future< PasskeyAssertion> -
Sign
challengewith the passkey, optionally constrained tocredentialId. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited