PasskeyRegistration class

The result of creating a passkey credential (WebAuthn create).

Constructors

PasskeyRegistration(Uint8List derSPKI, Uint8List credentialId)

Properties

credentialId Uint8List
The credential id (rawId), used to constrain later assertions.
final
derSPKI Uint8List
The DER SubjectPublicKeyInfo (secp256r1) from getPublicKey().
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited