SenderTransaction class

Constructors

SenderTransaction({required String digest, required int? timestampMs, required bool success, required List<TxBalanceChange> balanceChanges})

Properties

balanceChanges List<TxBalanceChange>
final
digest String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final
timestampMs int?
Execution timestamp in epoch milliseconds (null if unavailable).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited