TxObjectChange class
An object's ownership/state change within a transaction — enough to surface NFT (and other owned-object) transfers, which leave no balance change.
Constructors
Properties
- fromAddress → String?
-
Address owner before / after — null when the object isn't address-owned,
or was created (no
from) / deleted (noto).final - hashCode → int
-
The hash code for this object.
no setterinherited
- kind → String
-
created,deleted, ormutated.final - objectId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toAddress → String?
-
final
- type → String
-
Move type of the object (e.g.
0x…::nft::Nft), empty if unavailable.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited