ValidatorInfo class

Constructors

ValidatorInfo({required String? name, required String? suiAddress, required int votingPower, required int commissionRate, required BigInt nextEpochStake, required BigInt stakingPoolSuiBalance, required BigInt poolTokenBalance, required String? stakingPoolId, required int activationEpoch})

Properties

activationEpoch int
Epoch the staking pool was activated; the basis for APY estimation.
final
commissionRate int
final
hashCode int
The hash code for this object.
no setterinherited
name String?
final
nextEpochStake BigInt
final
poolTokenBalance BigInt
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stakingPoolId String?
Staking pool object id — the value StakedSui.pool_id references, used to link a stake back to its validator.
final
stakingPoolSuiBalance BigInt
final
suiAddress String?
final
votingPower int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited