objects property
Set of objects either referenced as inputs or produced as outputs by transactions included in this checkpoint.
In order to benefit from deduplication of objects that
appear in multiple transactions in this checkpoint, objects
will only be present here and the transactions.objects
field will not be populated.
Implementation
@$pb.TagNumber(7)
$4.ObjectSet get objects => $_getN(6);
Implementation
@$pb.TagNumber(7)
set objects($4.ObjectSet value) => $_setField(7, value);