safeMode property
Whether the system is running in a downgraded safe mode due to a non-recoverable bug.
This is set whenever we failed to execute advance_epoch, and ended up executing advance_epoch_safe_mode.
It can be reset once we are able to successfully execute advance_epoch.
The rest of the fields starting with safe_mode_ are accumulated during safe mode
when advance_epoch_safe_mode is executed. They will eventually be processed once we
are out of safe mode.
Implementation
@$pb.TagNumber(10)
$core.bool get safeMode => $_getBF(9);
Implementation
@$pb.TagNumber(10)
set safeMode($core.bool value) => $_setBool(9, value);